package cn.com.poc.knowledge;

import cn.com.poc.knowledge.aggregate.KnowledgeService;
import cn.com.yict.framemax.core.spring.SingleContextInitializer;
import com.vladsch.flexmark.html.HtmlRenderer;
import com.vladsch.flexmark.parser.Parser;
import com.vladsch.flexmark.util.ast.Document;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.poifs.filesystem.DirectoryEntry;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.MockitoAnnotations;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.context.web.WebAppConfiguration;

import javax.annotation.Resource;
import java.io.ByteArrayInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author alex.yao
 * @date 2025/2/6
 */
@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(initializers = SingleContextInitializer.class)
@WebAppConfiguration
public class KnowledgeServiceTest {

    @Resource
    private KnowledgeService knowledgeService;

    @Before
    public void setUp() {
        MockitoAnnotations.initMocks(this);
    }


    @Test
    public void test_delDocument() {
        knowledgeService.delDocument(138, 1071);
    }


    //    @Test
    public static void main(String[] args) throws IOException, InvalidFormatException {
        String r = "AI在艺术创作中的应用越来越多样，这里举几个有趣的例子：\n" +
                "\n" +
                "1.  **动态画布**：比如纽约有位艺术家用AI实时分析观众微表情，生成会「呼吸变色」的数字壁画，去年在MoMA展出时排队3小时才能体验5分钟。\n" +
                "    \n" +
                "2.  **气味交响乐**：伦敦一个实验剧团用GPT-4分析莎士比亚剧本情感曲线，控制128个微型香氛装置，让《仲夏夜之梦》的森林气息能跟着剧情起伏变化。\n" +
                "    \n" +
                "3.  **文物「生长」**：敦煌研究院最近用扩散模型推演壁画的千年褪色过程，观众戴上AR眼镜能看到飞天衣裙从氧化变黑逐渐恢复成初绘时的青金石蓝。\n" +
                "    \n" +
                "4.  **AI策展人**：苏富比去年拍卖会引入的算法，能根据买家过往竞拍记录，即时生成虚拟展厅，把不同拍品组合出专属艺术史叙事线。\n" +
                "    \n" +
                "\n" +
                "这些创新不是要取代艺术家，更像是给创作者装了「第三只手」——比如现在很多雕塑家会先用GAN生成1000个概念模型，再选最有灵气的3个手工打磨。最近威尼斯双年展有个获奖装置，就是人类雕刻家与AI迭代了147个版本才确定的最终形态。";
//        String markdownContent = readMarkdownFile("C:\\Users\\52747\\Desktop\\1.md");
        String htmlContent = convertMarkdownToHtml(r);
        convertHtmlToWord(htmlContent, "C:\\Users\\52747\\Desktop\\1.docx");
//

//        String html = "<p>AI在艺术创作中的应用越来越多样，这里举几个有趣的例子：</p><ol><li><p><strong>动态画布</strong>：比如纽约有位艺术家用AI实时分析观众微表情，生成会「呼吸变色」的数字壁画，去年在MoMA展出时排队3小时才能体验5分钟。</p></li><li><p><strong>气味交响乐</strong>：伦敦一个实验剧团用GPT-4分析莎士比亚剧本情感曲线，控制128个微型香氛装置，让《仲夏夜之梦》的森林气息能跟着剧情起伏变化。</p></li><li><p><strong>文物「生长」</strong>：敦煌研究院最近用扩散模型推演壁画的千年褪色过程，观众戴上AR眼镜能看到飞天衣裙从氧化变黑逐渐恢复成初绘时的青金石蓝。</p></li><li><p><strong>AI策展人</strong>：苏富比去年拍卖会引入的算法，能根据买家过往竞拍记录，即时生成虚拟展厅，把不同拍品组合出专属艺术史叙事线。</p></li></ol><p>这些创新不是要取代艺术家，更像是给创作者装了「第三只手」——比如现在很多雕塑家会先用GAN生成1000个概念模型，再选最有灵气的3个手工打磨。最近威尼斯双年展有个获奖装置，就是人类雕刻家与AI迭代了147个版本才确定的最终形态。</p>";
//        convertHtmlToWord(html, "C:\\Users\\52747\\Desktop\\1.docx");

    }

//    private static String readMarkdownFile(String filePath) {
//        try {
//            return new String(Files.readAllBytes(Paths.get(filePath)));
//        } catch (IOException e) {
//            e.printStackTrace();
//            return "";
//        }
//    }

    private static String convertMarkdownToHtml(String markdown) {
        Pattern p = Pattern.compile("(\r?\n(\\s*\r?\n)+)");
        Matcher m = p.matcher(markdown);
        String result = m.replaceAll("\r\n");

        Parser parser = Parser.builder().build();
        HtmlRenderer renderer = HtmlRenderer.builder().build();
        Document document = parser.parse(result);
        return renderer.render(document);
    }

    private static void convertHtmlToWord(String html, String outputPath) throws IOException {
        FileOutputStream outputStream = new FileOutputStream(outputPath);
        ByteArrayInputStream bais = new ByteArrayInputStream(html.getBytes());//将字节数组包装到流中
        POIFSFileSystem poifs = new POIFSFileSystem();
        DirectoryEntry directory = poifs.getRoot();
        directory.createDocument("WordDocument", bais);
        poifs.writeFilesystem(outputStream);
    }
}
